@@ -81,7 +81,8 @@ class Worker:
                 if len(messages) == 0:
                     break
                 for message in messages:
-                    self.process_message(message.content, func, blob_func)
+                    content = base64.b64decode(message.content).decode("utf-8")
+                    self.process_message(content, func, blob_func)
                     self.queue.delete_message(message)
         finally:
             state_row['ActiveCount'].value = 0
@@ -167,12 +168,24 @@ class Worker:
             lines = [l.strip() for l in chunk.decode().split("\r\n") if len(l.strip()) > 0]
             lines[0] = last_piece + lines[0]
             last_piece = lines[-1]
-            source_segments = [json.loads(unicodedata.normalize("NFKD", l))[0].strip() for l in lines[:-1]]
+            source_segments = []
+            for l in lines[:-1]:
+                l = unicodedata.normalize("NFKD", l).strip()
+                if len(l) == 0:
+                    continue
+                source_segment = json.loads(l)[0].strip()
+                source_segments.append(source_segment)
             yield source_segments
 
-        last_piece = json.loads(unicodedata.normalize("NFKD", last_piece))[0].strip()
-        if last_piece and len(last_piece) > 0:
-            yield [last_piece]
+        last_piece = unicodedata.normalize("NFKD", last_piece).strip()
+        if len(last_piece) > 0:
+            source = None
+            try:
+                source = json.loads(last_piece)[0].strip()
+            except:
+                pass
+            if source:
+                yield [source]
 
     @staticmethod
     def _generate_id(data):
